﻿
// ----------------------------------------------------------------------------------
//
// Copyright Microsoft Corporation
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ----------------------------------------------------------------------------------

using AutoMapper;
using Microsoft.Azure.Commands.Network.Models;
using Microsoft.Azure.Commands.Tags.Model;
using Microsoft.Azure.Management.Network;
using System.Net;

namespace Microsoft.Azure.Commands.Network
{
    public abstract class ExpressRouteCircuitBaseCmdlet : NetworkBaseCmdlet
    {
        public IExpressRouteCircuitsOperations ExpressRouteCircuitClient
        {
            get
            {
                return NetworkClient.NetworkManagementClient.ExpressRouteCircuits;
            }
        }

        public bool IsExpressRouteCircuitPresent(string resourceGroupName, string name)
        {
            try
            {
                GetExpressRouteCircuit(resourceGroupName, name);
            }
            catch (Microsoft.Rest.Azure.CloudException exception)
            {
                if (exception.Response.StatusCode == HttpStatusCode.NotFound)
                {
                    // Resource is not present
                    return false;
                }

                throw;
            }

            return true;
        }

        public PSExpressRouteCircuit GetExpressRouteCircuit(string resourceGroupName, string name)
        {
            var circuit = this.ExpressRouteCircuitClient.Get(resourceGroupName, name);

            var psExpressRouteCircuit = Mapper.Map<PSExpressRouteCircuit>(circuit);
            psExpressRouteCircuit.ResourceGroupName = resourceGroupName;

            psExpressRouteCircuit.Tag =
                TagsConversionHelper.CreateTagHashtable(circuit.Tags);

            return psExpressRouteCircuit;
        }

        public PSExpressRouteCircuit ToPsExpressRouteCircuit(Management.Network.Models.ExpressRouteCircuit circuit)
        {
            var psCircuit = Mapper.Map<PSExpressRouteCircuit>(circuit);

            psCircuit.Tag = TagsConversionHelper.CreateTagHashtable(circuit.Tags);

            return psCircuit;
        }
    }
}